# Tools for backend python services

[![PyPI version](https://badge.fury.io/py/metablock.svg)](https://badge.fury.io/py/aio-fluid)
[![build](https://github.com/quantmind/fluid/workflows/build/badge.svg)](https://github.com/quantmind/aio-fluid/actions?query=workflow%3Abuild)
[![codecov](https://codecov.io/gh/quantmind/fluid/branch/master/graph/badge.svg?token=81oWUoyEVp)](https://codecov.io/gh/quantmind/aio-fluid)

## Installation

This is a simple python package you can install via pip:

```
pip install aio-fluid
```
